// ###############################################################################
//									I2C Bus Strings
// ###############################################################################

#define EAPI_ID_I2C_INTERNAL		EAPI_UINT32_C(4)	// I2C for internal connected devices
#define EAPI_ID_I2C_MAX				EAPI_UINT32_C(5)	// Max Value

// ###############################################################################
//									Includes
// ###############################################################################

#include "EApi.h"

#include <stdio.h>
#include <math.h>

#ifdef CODE_for_WINDOWS
#include <comdef.h>
#include <winioctl.h>
#pragma once
#endif

#ifdef CODE_for_LINUX
#include <iostream>
#include <time.h>
#include <sys/times.h>
#include <unistd.h>
#include <fcntl.h>
#include <string.h>
#include <sys/ioctl.h>
#endif

#ifdef CODE_for_WINDOWS
#include <tchar.h>
#include <Wbemidl.h>
# pragma comment(lib, "wbemuuid.lib")
#endif

#define EAPI_MAX_LEN_STRING 128

// ###############################################################################
//							Board Information Strings
// ###############################################################################

#define EAPI_ID_HWMON_RAM_TEMP         EAPI_UINT32_C(0x50000) /* 0.1 Kelvins */
#define EAPI_ID_GET_SWITCH_STATUS      EAPI_UINT32_C(0x50001)
#define EAPI_ID_BOARD_PART_NUMBER_STR  EAPI_UINT32_C(0x50002)

#define SWITCH_STATUS_BOOT		0
#define SWITCH_STATUS_NORMAL	1



// ###############################################################################
//								PWM Management
// ###############################################################################

/* ---------------------------------------------------------------
 * - EApiPWM_Enable
 * - EApiPWM_Disable
 * - EApiPWM_GetCycle
 * - EApiPWM_SetCycle
 * - EApiPWM_GetDutyCycle
 * - EApiPWM_SetDutyCycle
 *
 * Theese functions allows to configure and control PWM on FAN connector.
 *
 * Parameter:
 *
 * Cycle -> Pointer to a buffer that receives the current PWM Cycle value:
 *          Q7-974, Q7-A36, uQ7-A76-J, Q7-B03, COMe-A98-CT6, COMe-B09-BT6, COMe-B75-CT6, COMe-B72-CT6, COMe-C08-BT6, COMe-C89-BT6, COMe-C91-BT6, COMe-C24-CT6, COMe-C55-CT6, SM-B69:
 *                   Frequency value expressed in Hz(0 - 65535 Hz)
 *          SBC-A44-pITX, SBC-C41-pITX, SBC-C90, UDOO Bolt:
 *                   No external fan supported
 *
 * Duty Cycle -> Percent value (0-100)
 *
 */

#define PWM_ID_INTFAN	0
#define PWM_ID_EXTFAN	1

/*
 * EApiPWMEnable
 *
 * Parameter:
 *
 * Cycle -> Pointer to a buffer that receives the current PWM Cycle value:
 *          Q7-974, Q7-A36, uQ7-A76-J, Q7-B03, COMe-A98-CT6, COMe-B09-BT6, COMe-B75-CT6, COMe-B72-CT6, COMe-C08-BT6, COMe-C89-BT6, COMe-C91-BT6, COMe-C24-CT6, COMe-C55-CT6, SM-B69:
 *                   Frequency value expressed in Hz(0 - 65535 Hz)
 *          SBC-A44-pITX, SBC-C41-pITX, SBC-C90, UDOO Bolt:
 *                   No external fan supported
 *
 * Duty Cycle -> Percent value (0-100)
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * DutyCycle > 100                    | EAPI_STATUS_INVALID_PARAMETER
 * Cycle > MAX_CYCLE_STEPS            | EAPI_STATUS_INVALID_PARAMETER
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiPWMEnable(__IN  uint8_t PWM_ID,
               __IN  uint32_t Cycle,	        /* New Fan PWM Cycle */
			   __IN  uint8_t DutyCycle		/* New Fan PWM Duty Cycle */
			  );

/*
 * EApiPWMDisable
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiPWMDisable(__IN  uint8_t PWM_ID);

/*
 * EApiPWMGetCycle
 *
 * Parameter:
 *
 * Cycle -> Pointer to a buffer that receives the current PWM Cycle value:
 *          Q7-974, Q7-A36, uQ7-A76-J, Q7-B03, COMe-A98-CT6, COMe-B09-BT6, COMe-B75-CT6, COMe-B72-CT6, COMe-C08-BT6, COMe-C89-BT6, COMe-C91-BT6, COMe-C24-CT6, COMe-C55-CT6, SM-B69:
 *                   Frequency value expressed in Hz(0 - 65535 Hz)
 *          SBC-A44-pITX, SBC-C41-pITX, SBC-C90, UDOO Bolt:
 *                   No external fan supported
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiPWMGetCycle(__IN  uint8_t PWM_ID,
	             __OUT  uint32_t * Cycle	/* Current Fan PWM Cycle */
                );

/*
 * EApiPWMSetCycle
 *
 * Parameter:
 *
 * Cycle -> Pointer to a buffer that receives the current PWM Cycle value:
 *          Q7-974, Q7-A36, uQ7-A76-J, Q7-B03, COMe-A98-CT6, COMe-B09-BT6, COMe-B75-CT6, COMe-B72-CT6, COMe-C08-BT6, COMe-C89-BT6, COMe-C91-BT6, COMe-C24-CT6, COMe-C55-CT6, SM-B69:
 *                   Frequency value expressed in Hz(0 - 65535 Hz)
 *          SBC-A44-pITX, SBC-C41-pITX, SBC-C90, UDOO Bolt:
 *                   No external fan supported
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Cycle > MAX_CYCLE_STEPS            | EAPI_STATUS_INVALID_PARAMETER
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiPWMSetCycle(__IN  uint8_t PWM_ID,
	             __IN  uint32_t Cycle		/* New Fan PWM Cycle */
                );

/*
 * EApiPWMGetDutyCycle
 *
 * Parameter:
 *
 * Duty Cycle -> Percent value (0-100)
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiPWMGetDutyCycle(__IN  uint8_t PWM_ID,
	                 __OUT  uint8_t * DutyCycle	/* Current Fan PWM Duty Cycle */
                    );

/*
 * EApiPWMSetDutyCycle
 *
 * Parameter:
 *
 * Cycle -> Pointer to a buffer that receives the current PWM Cycle value:
 *          Q7-974, Q7-A36, uQ7-A76-J, Q7-B03, COMe-A98-CT6, COMe-B09-BT6, COMe-B75-CT6, COMe-B72-CT6, COMe-C08-BT6, COMe-C89-BT6, COMe-C91-BT6, COMe-C24-CT6, COMe-C55-CT6, SM-B69:
 *                   Frequency value expressed in Hz(0 - 65535 Hz)
 *          SBC-A44-pITX, SBC-C41-pITX, SBC-C90, UDOO Bolt:
 *                   No external fan supported
 *
 * Duty Cycle -> Percent value (0-100)
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * DutyCycle > 100                    | EAPI_STATUS_INVALID_PARAMETER
 * Cycle > MAX_CYCLE_STEPS            | EAPI_STATUS_INVALID_PARAMETER
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiPWMSetDutyCycle(__IN  uint8_t PWM_ID,
	                 __IN  uint32_t Cycle,    	/* New Fan PWM Cycle */
					 __IN  uint8_t DutyCycle		/* New Fan PWM Duty Cycle */
					);



// ###############################################################################
//									Watchdog
// ###############################################################################
//
//	- EApiWDog_SetConfig
//
//	 This function can be used to set additional parameter for Watch Dog not provided by EAPI standard
//	 definition. It's possible to set timeout, delay and mode:
//	 The mode value refers to the following modality:
//
//	Watch Dog event:
//		- Signalation (EAPI_WTD_MODE_SIGNAL)
//				Signalation on WDOUT / WDT signal.
//				Supported by:
//					0978 (Q7) -> WDOUT signal on pin 72 on Q7 connector
//					0974 (Q7) -> WDOUT signal on pin 72 on Q7 connector
//					0902 (COMEx) -> WDT signal on pin B27 on ComEx connector
//					0953 (COMEx) -> WDT signal on pin B27 on ComEx connector
//					0948 (COMEx) -> WDT signal on pin B27 on ComEx connector
//
//		- Power button after 1 second (EAPI_WTD_MODE_PWRBTN_1SEC)
//			Supported by:
//				0978 / 0974 (Q7)
//				0902 / 0953 / 0948 (COMEx)
//
//		- Power button after 4 second (EAPI_WTD_MODE_PWRBTN_4SEC)
//			Supported by:
//				0978 / 0974 (Q7)
//				0902 / 0953 / 0948 (COMEx)
//
//		- Reset (EAPI_WTD_MODE_SYSTEM_RESET)
//			Supported by:
//				0978 / 0974 (Q7)
//				0902 / 0953 / 0948 (COMEx)
//
//	Watch Dog trigger:
//		- Software trigger (EAPI_WTD_MODE_ENABLE_SW_TRIGGER)
//			Enable software trigger using EApiWDogTrigger function
//				Supported by all boards.
//		- Hardware trigger (EAPI_WTD_MODE_ENABLE_HW_TRIGGER)
//			Enable hardware trigger using WDTRIG signal
//				Supported by:
//					0978 (Q7) -> WDTRIG# signal on pin 70 of Q7 connector
//					0974 (Q7) -> WDTRIG# signal on pin 70 of Q7 connector
//
//	 Note that Watchdog Modes are mutually exclusive.
//	 The Watchdog has been specified as a single stage Watchdog that resets the system when timed out.
//
//	Refer to Eapi_Seco.h for additional information
//	Refer to EAPI_Supported_Functions.pdf for complete support plan.

/* Watch Dog Event */
#define EAPI_WTD_MODE_SIGNAL				0x01 /* Supported by: 0978 / 0974 / 0902 / 0953 / 0948 */
#define EAPI_WTD_MODE_SYSTEM_RESET			0x02 /* Supported by: 0978 / 0974 / 0902 / 0953 / 0948 */
#define EAPI_WTD_MODE_PWRBTN_1SEC			0x03 /* Supported by: 0978 / 0974 / 0902 / 0953 / 0948 */
#define EAPI_WTD_MODE_PWRBTN_4SEC			0x04 /* Supported by: 0978 / 0974 / 0902 / 0953 / 0948 */
#define EAPI_WTD_MODE_COLD_RESET			0x05 /* Supported by: -- */
#define EAPI_WTD_MODE_WARM_RESET			0x06 /* Supported by: -- */

/* Watch Dog Timeout/Delay time unit */
#define EAPI_WTD_MODE_IN_MSEC				0x00 /* Supported by: 0978 / 0974 / 0902 / 0953 / 0948 */
#define EAPI_WTD_MODE_DELAY_IN_MINUTES		0x80 /* Supported by: -- */
#define EAPI_WTD_MODE_TIMEOUT_IN_MINUTES	0x40 /* Supported by: -- */

/* Watch Dog trigger type */
#define EAPI_WTD_MODE_ENABLE_HW_TRIGGER		0x20 /* Supported by: 0978 / 0974 */
#define EAPI_WTD_MODE_ENABLE_SW_TRIGGER		0x10 /* Supported by: 0978 / 0974 / 0902 / 0953 / 0948 */

/*
 * EApiWDog_SetConfigAndStart
 *
 * Supported Q7 board: 0747 / 0866
 * Supported COMEx board: -
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiWDog_SetConfigAndStart(__IN  uint32_t delay_Timeout_msec, 	/* Delay in msec */
						   __IN  uint32_t event_Timeout_msec, 	/* Event in msec */
						   __IN  uint32_t reset_Timeout_msec, 	/* Reset in msec */
						   __IN  uint32_t mode_Event		, 	/* Watch Dog Event (EAPI_WTD_MODE_SIGNAL or
																					EAPI_WTD_MODE_SYSTEM_RESET or
																					EAPI_WTD_MODE_PWRBTN_1SEC or
																					EAPI_WTD_MODE_PWRBTN_4SEC) */
						   __IN  uint8_t mode_Timeout_unit	,	/* Watch Dog Timeout time unit (EAPI_WTD_MODE_IN_MSEC)*/
						   __IN  uint8_t mode_Delay_unit	,	/* Watch Dog Delay time unit (EAPI_WTD_MODE_IN_MSEC)*/
						   __IN  uint8_t mode_Trigger_Type	);	/* Watch Dog trigger type (EAPI_WTD_MODE_ENABLE_HW_TRIGGER or
																						   EAPI_WTD_MODE_ENABLE_SW_TRIGGER)*/




// ###############################################################################
//								GPIO Carrier Control
// ###############################################################################

// ---------------------------------------------------------------
// - EApiSetCarrier

#define CARRIER_NONE	0
#define CARRIER_M799	1
#define CARRIER_M901	2
#define CARRIER_0A19	3
#define CARRIER_0A42	4
#define CARRIER_0857	5
#define CARRIER_0A83	6
#define CARRIER_0B11	7

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiSetCarrier (__IN  uint8_t Carrier_ID);



// ###############################################################################
//									Reset Causes
// ###############################################################################

// ---------------------------------------------------------------
// - EApiGetResetCauses
// - EApiSetResetCauses
//
// The EApi library allows you to get and clear Reset Causes
//
// The system can be reset due to:
// - Reset button pressed (RESET_CAUSE_RESET)
// - WDT timeout expired (RESET_CAUSE_WDT)
// - Power faliure (RESET_CAUSE_PWFAIL)
// ---------------------------------------------------------------

#define RESET_CAUSE_RESET       ( 1 << 0 )
#define RESET_CAUSE_WDT         ( 1 << 1 )
#define RESET_CAUSE_PWFAIL      ( 1 << 2 )
#define RESET_CAUSE_SWRESET     ( 1 << 3 )

/*
 * EApiGetResetCauses
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiGetResetCauses(uint32_t * ResetCauses);

/*
 * EApiClearResetCauses
 *
 * Condition                          | Return Values * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiClearResetCauses(uint32_t ResetCauses);





// ###############################################################################
//									SPI Functions
// ###############################################################################


EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiSPIGetBusCap(
    __OUT uint32_t *pMaxBlkLen   /* Max Block Length
                                  * Supported on this
                                  * interface
                                  */
    );

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiSPIWriteReadRaw(__IN     uint16_t config,
					__IN     unsigned char CS,
					__INOPT  void     *pWBuffer , /* Write Data pBuffer */
					__IN     uint32_t  WriteBCnt, /* Number of Bytes to
												   * write plus 1
												   */
					__OUTOPT void     *pRBuffer , /* Read Data pBuffer */
					__IN     uint32_t  ReadBCnt /* Number of Bytes to Read */
					);

#define EApiSPIWriteRaw(config, CS, pBuffer, ByteCnt)         \
          EApiSPIWriteReadRaw(config, CS, pBuffer, ByteCnt, NULL, 0, 0)
#define EApiSPIReadRaw(config, CS, pBuffer, BufLen, ByteCnt) \
          EApiSPIWriteReadRaw(config, CS, NULL, 0, pBuffer, BufLen, ByteCnt)






// ###############################################################################
//									EDID EEPROM
// ###############################################################################

#define EDID_SIZE 21

/*
 * EApiEDIDRead
 *
 * Condition                              | Return Values
 * ---------------------------------------+------------------------------
 * Library Uninitialized                  | EAPI_STATUS_NOT_INITIALIZED
 * pBuffer==NULL                          | EAPI_STATUS_INVALID_PARAMETER
 * Read Error                             | EAPI_STATUS_READ_ERROR
 * BufLen>EDID_SIZE                       | EAPI_STATUS_MORE_DATA
 * Common Error                           | Common Error Code
 * Else                                   | EAPI_STATUS_SUCCESS
 */
EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiEDIDRead(
	__OUT     void* pBuffer, /* Pointer to Data pBuffer */
	__IN  uint32_t  BufLen    /* Data pBuffer Size in
							   * bytes
							   */
);
/*
 * EApiEDIDWrite
 *
 * Condition                              | Return Values
 * ---------------------------------------+------------------------------
 * Library Uninitialized                  | EAPI_STATUS_NOT_INITIALIZED
 * pBuffer==NULL                          | EAPI_STATUS_INVALID_PARAMETER
 * Write Error                            | EAPI_STATUS_WRITE_ERROR
 * BufLen>EDID_SIZE                       | EAPI_STATUS_MORE_DATA
 * Common Error                           | Common Error Code
 * Else                                   | EAPI_STATUS_SUCCESS
 */
EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiEDIDWrite(
	__IN      void* pBuffer, /* Pointer to Data pBuffer */
	__IN  uint32_t  BufLen    /* Data pBuffer Size in
							   * bytes
							   */
);















// ###############################################################################
//									Other Functions
// ###############################################################################


/*
 * EApiPowerRailCycle
 *
 * Condition                          | Return Values * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiPowerRailCycle(void);



// ###############################################################################
//				Serial port configuration on PicoITX (0799 and 0901)
// ###############################################################################

// ---------------------------------------------------------------
// - EApiGPIOGetSerialCfg
// - EApiGPIOSetSerialCfg
//
// The EApi library allows you to configure the serial port present on SECO picoITX carrier board (0799 and 0901)
// as RS232 or RS485 or RS422.
// With 'EApiGPIOGetSerialCfg' and 'EApiGPIOSetSerialCfg' functions you can get and set serial port
// configuration using the following defines:
//	GPIO_SERIAL_MODE_RS232
//	GPIO_SERIAL_MODE_RS422
//	GPIO_SERIAL_MODE_RS485TX
//	GPIO_SERIAL_MODE_RS485RX
// ---------------------------------------------------------------

/* Serial Port Configuration */
#define GPIO_SERIAL_MODE_RS232		0xA1
#define GPIO_SERIAL_MODE_RS422		0xA2
#define GPIO_SERIAL_MODE_RS485TX	0xA3
#define GPIO_SERIAL_MODE_RS485RX	0xA4


EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiGPIOGetSerialCfg(__OUT  uint8_t* GPIO_SERIAL_MODE);

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiGPIOSetSerialCfg(__IN  uint8_t GPIO_SERIAL_MODE);



// ###############################################################################
//							Utility Function - Not supported
// ###############################################################################

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiEnableDebugLog(__IN  bool Value);




// ###############################################################################
//						W83627DHG_P SuperIO Support Functions
// ###############################################################################

// ---------------------------------------------------------------
//
// EAPI library provide functions for using some W83627DHG_P
// hardware monitor capabilities:
//	- Read CPUTIN temperature
//	- Read 3.3V Voltage
//	- Read VIN1 (5V) Voltage
//	- Read VIN0 (Bright) Voltage
//	- Read CPUFANIN speed
//	- Read SYSFANIN speed
//	- Read/Write CPUFANOUT (PWM)
//	- Read/Write SYSFANOUT (Analog)
//
// Futhermore, EAPI manage also the following GPIO's:
//	- GP20
//	- GP21
//	- GP22
//	- GP23
//
// ---------------------------------------------------------------
//
// Additional parameter for standard EApiBoardGetValue function were added to access
// to W83627DHG_P hardware monitor:
//
//	- EAPI_ID_HWMON_CHIPSET_TEMP_W83627DHG_P for reading CPUTIN temperature.
//		The returned vaule is a temperature expressed in 0.1 Kelvins
//	- EAPI_ID_HWMON_VOLTAGE_3V3_W83627DHG_P for reading 3.3V Voltage
//		The returned vaule is a voltage expressed in millivolts
//	- EAPI_ID_HWMON_VOLTAGE_5V_W83627DHG_P for reading VIN1(5V) Voltage
//		The returned vaule is a voltage expressed in millivolts
//	- EAPI_ID_HWMON_VOLTAGE0_W83627DHG_P for reading VIN0(Bright) Voltage
//		The returned vaule is a voltage expressed in millivolts
//	- EAPI_ID_HWMON_FAN_CPU_W83627DHG_P for reading CPUFANIN speed
//		The returned vaule is a fan speed expressed in RMP
//	- EAPI_ID_HWMON_FAN_SYSTEM_W83627DHG_P for reading SYSFANIN speed
//		The returned vaule is a fan speed expressed in RMP

#define EAPI_ID_HWMON_CHIPSET_TEMP_W83627DHG_P	EAPI_UINT32_C(0x20003) /* Return Value 0.1 Kelvins */
#define EAPI_ID_HWMON_VOLTAGE_3V3_W83627DHG_P	EAPI_UINT32_C(0x24000) /* Return Value millivolts */
#define EAPI_ID_HWMON_VOLTAGE_5V_W83627DHG_P	EAPI_UINT32_C(0x24001) /* Return Value millivolts */
#define EAPI_ID_HWMON_VOLTAGE_12V_W83627DHG_P	EAPI_UINT32_C(0x24002) /* Return Value millivolts */
#define EAPI_ID_HWMON_VOLTAGE0_W83627DHG_P		EAPI_UINT32_C(0x24003) /* Return Value millivolts */
#define EAPI_ID_HWMON_FAN_CPU_W83627DHG_P		EAPI_UINT32_C(0x24004) /* Return Value RPM */
#define EAPI_ID_HWMON_FAN_SYSTEM_W83627DHG_P	EAPI_UINT32_C(0x24005) /* Return Value RPM */

// ---------------------------------------------------------------
//
// New functions have been introduced to handle speed fan
//
//	EApiFanEnable_W83627DHG_P
//	EApiFanDisable_W83627DHG_P
//	EApiFanPWMGetDutyCycle_W83627DHG_P
//	EApiFanPWMSetDutyCycle_W83627DHG_P

//
// In each function is neccessry to indicate the Fan to manage with the following defines:

#define FAN_CPU	0
#define FAN_SYS	1

/*
 * EApiFanEnable_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * DutyCycle > 100                    | EAPI_STATUS_INVALID_PARAMETER
 * Cycle > MAX_CYCLE_STEPS            | EAPI_STATUS_INVALID_PARAMETER
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanEnable_W83627DHG_P(__IN  uint8_t Fan,	/* Fan Selection */
	__IN  uint8_t DutyCycle		/* New Fan PWM Duty Cycle */
);

/*
 * EApiFanDisable_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanDisable_W83627DHG_P(__IN  uint8_t Fan);	 /* Fan Selection */

/*
 * EApiFanPWMGetDutyCycle_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanPWMGetDutyCycle_W83627DHG_P(__IN  uint8_t Fan,	/* Fan Selection */
	__OUT  uint8_t* Value);		/* Current Fan PWM Duty Cycle */

/*
 * EApiFanPWMSetDutyCycle_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * DutyCycle > 100                    | EAPI_STATUS_INVALID_PARAMETER
 * Cycle > MAX_CYCLE_STEPS            | EAPI_STATUS_INVALID_PARAMETER
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanPWMSetDutyCycle_W83627DHG_P(__IN  uint8_t Fan,	/* Fan Selection */
	__IN  uint8_t DutyCycle		/* New Fan PWM Duty Cycle */
);

/*
 * EApiGetVoltage_0_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiGetVoltage_0_W83627DHG_P(__IN  uint32_t * pValue);

/*
 * EApiGet3V3_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiGet3V3_W83627DHG_P(__IN  uint32_t * pValue);

/*
 * EApiGet5V_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiGet5V_W83627DHG_P(__IN  uint32_t * pValue);

/*
 * EApiGet12V_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiGet12V_W83627DHG_P(__IN  uint32_t * pValue);

/*
 * EApiFanCPUMonitor_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanCPUMonitor_W83627DHG_P(__IN  uint32_t *pValue);

/*
 * EApiFanSystemMonitor_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanSystemMonitor_W83627DHG_P(__IN  uint32_t *pValue);

/*
 * EApiGetChipsetTemperature_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiGetChipsetTemperature_W83627DHG_P(__IN  unsigned long * Temperature);

/*
 * EApiGetResetCauses_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiGetResetCauses_W83627DHG_P(__IN  uint32_t * ResetCauses);

/*
 * EApiClearResetCauses_W83627DHG_P
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiClearResetCauses_W83627DHG_P(__IN  uint32_t ResetCauses);


// ###############################################################################
//							Deprecated functions
// ###############################################################################

/*
 * EApiFanEnable
 *
 * Parameter:
 *
 * Cycle -> Pointer to a buffer that receives the current PWM Cycle value:
 *          Q7-974, Q7-A36, uQ7-A76-J, Q7-B03, COMe-A98-CT6, COMe-B09-BT6, COMe-B75-CT6, COMe-B72-CT6, COMe-C08-BT6, COMe-C89-BT6, COMe-C91-BT6, COMe-C24-CT6, COMe-C55-CT6, SM-B69:
 *                   Frequency value expressed in Hz(0 - 65535 Hz)
 *          SBC-A44-pITX, SBC-C41-pITX, SBC-C90, UDOO Bolt:
 *                   No external fan supported
 *
 * Duty Cycle -> Percent value (0-100)
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * DutyCycle > 100                    | EAPI_STATUS_INVALID_PARAMETER
 * Cycle > MAX_CYCLE_STEPS            | EAPI_STATUS_INVALID_PARAMETER
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanEnable(__IN  uint32_t Cycle,	/* New Fan PWM Cycle */
	__IN  uint8_t DutyCycle		/* New Fan PWM Duty Cycle */
);

/*
 * EApiFanDisable
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanDisable(void);

/*
 * EApiFanPWMGetCycle
 *
 * Parameter:
 *
 * Cycle -> Pointer to a buffer that receives the current PWM Cycle value:
 *          Q7-974, Q7-A36, uQ7-A76-J, Q7-B03, COMe-A98-CT6, COMe-B09-BT6, COMe-B75-CT6, COMe-B72-CT6, COMe-C08-BT6, COMe-C89-BT6, COMe-C91-BT6, COMe-C24-CT6, COMe-C55-CT6, SM-B69:
 *                   Frequency value expressed in Hz(0 - 65535 Hz)
 *          SBC-A44-pITX, SBC-C41-pITX, SBC-C90, UDOO Bolt:
 *                   No external fan supported
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanPWMGetCycle(__OUT  uint32_t* Cycle);	/* Current Fan PWM Cycle */

/*
 * EApiFanPWMSetCycle
 *
 * Parameter:
 *
 * Cycle -> Pointer to a buffer that receives the current PWM Cycle value:
 *          Q7-974, Q7-A36, uQ7-A76-J, Q7-B03, COMe-A98-CT6, COMe-B09-BT6, COMe-B75-CT6, COMe-B72-CT6, COMe-C08-BT6, COMe-C89-BT6, COMe-C91-BT6, COMe-C24-CT6, COMe-C55-CT6, SM-B69:
 *                   Frequency value expressed in Hz(0 - 65535 Hz)
 *          SBC-A44-pITX, SBC-C41-pITX, SBC-C90, UDOO Bolt:
 *                   No external fan supported
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Cycle > MAX_CYCLE_STEPS            | EAPI_STATUS_INVALID_PARAMETER
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanPWMSetCycle(__IN  uint32_t Cycle);		/* New Fan PWM Cycle */

/*
 * EApiFanPWMGetDutyCycle
 *
 * Parameter:
 *
 * Duty Cycle -> Percent value (0-100)
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanPWMGetDutyCycle(__OUT  uint8_t* DutyCycle);	/* Current Fan PWM Duty Cycle */

/*
 * EApiFanPWMSetDutyCycle
 *
 * Parameter:
 *
 * Cycle -> Pointer to a buffer that receives the current PWM Cycle value:
 *          Q7-974, Q7-A36, uQ7-A76-J, Q7-B03, COMe-A98-CT6, COMe-B09-BT6, COMe-B75-CT6, COMe-B72-CT6, COMe-C08-BT6, COMe-C89-BT6, COMe-C91-BT6, COMe-C24-CT6, COMe-C55-CT6, SM-B69:
 *                   Frequency value expressed in Hz(0 - 65535 Hz)
 *          SBC-A44-pITX, SBC-C41-pITX, SBC-C90, UDOO Bolt:
 *                   No external fan supported
 *
 * Duty Cycle -> Percent value (0-100)
 *
 * Condition                          | Return Values
 * -----------------------------------+------------------------------
 * DutyCycle > 100                    | EAPI_STATUS_INVALID_PARAMETER
 * Cycle > MAX_CYCLE_STEPS            | EAPI_STATUS_INVALID_PARAMETER
 * Unsupported board                  | EAPI_STATUS_UNSUPPORTED
 * Common Error                       | Common Error Code
 * Else                               | EAPI_STATUS_SUCCESS
 */

EAPI_LIB_DEF
EApiStatus_t
EAPI_CALLTYPE
EApiFanPWMSetDutyCycle(__IN  uint32_t Cycle,	/* New Fan PWM Cycle */
	__IN  uint8_t DutyCycle		/* New Fan PWM Duty Cycle */
);